candidate_offsets

Function candidate_offsets 

pub fn candidate_offsets(stride: f64, num: usize) -> Vec<Vec2> 
Deterministic polar sampling of candidate offsets around the origin on a circle of the given stride radius.