pub fn wall_repulsion(
p: &Pedestrian,
wall: &WallSegment,
params: &Params,
) -> Vec2Expand description
Repulsion from the closest point on a wall segment.
pub fn wall_repulsion(
p: &Pedestrian,
wall: &WallSegment,
params: &Params,
) -> Vec2Repulsion from the closest point on a wall segment.