step_layered_scratch

Function step_layered_scratch 

pub fn step_layered_scratch(
    peds: &mut [Pedestrian3D],
    space: &LayeredSpace,
    planar_step: PlanarStepFn,
    params: &Params,
    dt: f64,
    scratch: &mut LayeredScratch,
)
Zero-allocation variant of step_layered.

Semantics are identical to step_layered; the only difference is that all working buffers are borrowed from scratch and their capacities are preserved across calls.